@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: haskell-src-exts
 version: 1.17.1
-id: haskell-src-exts-1.17.1-22ac2cdd01c70a173d0a3e75bc933334
-key: haske_HaPRS6kcbmr9JGv457YYhN
+id: haskell-src-exts-1.17.1-a439f7709447829586f6c45dee78a187
+key: haske_4FklJxiwJoAI0XtFimUoU7
 license: BSD3
 maintainer: Niklas Broberg <niklas.broberg@chalmers.se>, Roman Cheplyaka <roma@ro-che.info>
 stability: Stable
@@ -56,11 +56,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/haskell-src-exts-1.17.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/haskell-src-exts-1.17.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/haskell-src-exts-1.17.1
-hs-libraries: HShaskell-src-exts-1.17.1-HaPRS6kcbmr9JGv457YYhN
+hs-libraries: HShaskell-src-exts-1.17.1-4FklJxiwJoAI0XtFimUoU7
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    cpphs-1.20.1-b531b91e3eedabd84a3f357cbe12d473
+    cpphs-1.20.1-871062ee45047e2f85948c7199a03a26
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
 haddock-interfaces: /usr/share/doc/haskell-src-exts/html/haskell-src-exts.haddock
